package edu.nyu.scps.location;

import android.content.Context;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.location.LocationProvider;
import android.os.Bundle;
import android.support.v7.app.ActionBarActivity;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.TextView;


public class MainActivity extends ActionBarActivity implements LocationListener {
    LocationManager locationManager;
    TextView textView;
    TextView messages;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        locationManager = (LocationManager)getSystemService(Context.LOCATION_SERVICE);
        textView = (TextView)findViewById(R.id.textView);
        messages = (TextView)findViewById(R.id.messages);
    }

    //GPS is expensive, so use it only when app is exposed on screen.

    @Override
    public void onResume() {
        super.onResume();
        locationManager.requestLocationUpdates(
                LocationManager.GPS_PROVIDER,	//or LocationManager.NETWORK_PROVIDER, or both
                0L,		//minimum time interval (milliseconds) between notifications
                0.0f,		//minimum change in distance (meters) between notifications
                this
        );
    }

    @Override
    public void onPause() {
        super.onPause();
        locationManager.removeUpdates(this);
    }

    @Override
    public void onLocationChanged(Location location) {
        // Called when a new location is found by the network location provider.
        double latitude = location.getLatitude();
        double longitude = location.getLongitude();

        String s = String.format(
                  "Latitude  %20.15g\u00B0\n"   //Unicode degree symbol
                + "Longitude %20.15g\u00B0\n",
                latitude, longitude
        );

        textView.setText(s);
    }

    @Override
    public void onStatusChanged(String provider, int status, Bundle extras) {
        textView.append("Status of provider " + provider + " has changed to ");
        String s;

        switch (status) {
            case LocationProvider.OUT_OF_SERVICE:
                s = "OUT_OF_SERVICE";
                break;
            case LocationProvider.TEMPORARILY_UNAVAILABLE:
                s = "TEMPORARILY_UNAVAILABLE";
                break;
            case LocationProvider.AVAILABLE:
                s = "AVAILABLE";
                break;
            default:
                s = "unknown";
                break;
        }

        textView.append(s + "\n");
        if (extras != null) {
            messages.append(extras.toString() + "\n");
        }
        messages.append("\n");
    }

    @Override
    public void onProviderEnabled(String provider) {
        messages.append("onProviderEnabled " + provider);
    }

    @Override
    public void onProviderDisabled(String provider) {
        messages.append("onProviderDisabled " + provider);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }
}
